const { createElement, render, useState,useEffect,Fragment} = wp.element;

import QuizTimer from './quiztimer.js';

import Smalltext from './smalltext.js';
import Single from './single.js';
import Select from './select.js';
import Multiple from './multiple.js';
import Fillblank from './fillblank.js';
import Sort from './sort.js';
import Match from './match.js';
import TrueFalse from './truefalse.js';
import Largetext from './largetext.js';

import evaluatequestion from './services/evaluatequestion.js';
import getCorrectAnswer from './services/showcorrectanswer.js';
import CryptoJS from './libs/crypto.js';
import CryptoJSAesJson from './services/cryptoaes.js';

import CheckAnswer from './components/checkanswer.js';
import QuestionHint from './components/questionhint.js';
import QuestionList from './components/questionlist.js';
import QuizBar from './components/quizbar.js';
import QuizPagination from './components/quizpagination.js';
import ConfirmPopup from './components/confirmpopup.js';
import QuizStatsChart from './components/quizstatschart.js';




function isEmpty(obj){
    if (obj == null) return true;
    if (typeof obj == 'number') return true;
    if (Array.isArray(obj) || typeof obj === 'string' || obj instanceof String) return obj.length === 0;
    for (var key in obj) if (obj.hasOwnProperty(key)) return false;
    return true;
}	
function isJson(str) {
    try {
        JSON.parse(str);
    } catch (e) {
        return false;
    }
    return true;
}

const VibeQuiz = (props) => {
	const [quiz,setQuiz] = useState({});
	const [ready,setReady] = useState(false);
	const [currentQuestions,setCurrentQuestions] = useState([]);


	const [ref,setRef] = useState(null);
	const [translatey,setTranslateY] = useState(0);

	const [startPopupActive,setstartPopupActive] = useState(false);
	const [submitPopupActive,setsubmitPopupActive] =useState(false);

	useEffect(()=>{

		fetch(window.wplms_quiz_data.api_url+'/user/quiz/'+props.quizid , {
		    headers: {
		      'Content-Type': 'application/json',
		      'Authorization':window.wplms_quiz_data.token
		    }
		}).then( res => res.json())
      	.then(
          	(data) => {
	          	if(data){
	          		
	          		if(data.meta && data.meta.questions){
	          			let user_marks = 0;
						let max_marks = 0;
						if(typeof data.meta.questions == 'object' && !Array.isArray(data.meta.questions)){
							let nquestions =[];
							Object.keys(data.meta.questions).map((key)=>{
								if(typeof data.meta.questions[key] == 'object'){
									data.meta.questions[key]['id']=key;
									nquestions.push(data.meta.questions[key]);
									nquestions['id'] = key;
								}
							});
							data.meta.questions = nquestions;
						}

	          			data.meta.questions.map((question,i)=>{
	          				if(question['raw']){
	          					data.meta.questions[i] = question['raw'];
	          				}else{
	          					data.meta.questions[i]['show'] = false;
		          				let checkStorage = localStorage.getItem(question.id);
		          				if(!isEmpty(checkStorage) && isEmpty(question['marked_answer'])){
		          					if(isJson(checkStorage)){
		          						question['marked_answer'] = JSON.parse(checkStorage);
		          					}else{
		          						question['marked_answer'] = checkStorage;
		          					}
		          				}
		          				if(question.attempted){
		          					data.meta.questions[i].correct = JSON.parse(CryptoJS.AES.decrypt(question.correct, question.key, {format: CryptoJSAesJson}).toString(CryptoJS.enc.Utf8));
	    							question.correct = getCorrectAnswer(question); 
		          				}
	          				}
	          				user_marks += parseFloat(question['marks']);
	          				max_marks += parseInt(question['max_marks']);
	          			});
	          			if(!Number.isInteger(user_marks)){
	          				user_marks = user_marks.toFixed(2);
	          			}
	          			data['marks'] = user_marks;
						data['max_marks'] = max_marks;

	          			data.question_number = parseInt(data.question_number);
	          			let ncurrentQuestions=[];
	          			if(data.question_number && data.question_number > 0){
	          				for(let i=0;i<data.question_number;i++){
	          					ncurrentQuestions.push(i);
	          				}
	          			}
	          			setCurrentQuestions(ncurrentQuestions);
	          			setQuiz(data);
	          			setReady(true);
	          		}
	          		if((data.remaining && data.remaining <= 0)){
	          			SubmitQuiz(data);
	          		}

	          		var event = document.createEvent("Event");
					event.initEvent("unit_traverse", false, true);
					if(document.querySelector('.unit_content') && document.querySelector('.unit_content')){
						
						document.querySelector('.unit_content').dispatchEvent(event);	
					}
	          	}else{
	          		console.log(data);
	          	}
          	}
		);


	},[]);

	useEffect(()=>{
		if(ref){
			var timer = null;
			window.addEventListener('scroll', ()=>{
				var scrollTopx = (window.pageYOffset !== undefined) ? window.pageYOffset : (document.documentElement || document.body.parentNode || document.body).scrollTop;
				if(timer !== null) {
			        clearTimeout(timer);        
			    }
			    timer = setTimeout(function() {
			         if(0 < scrollTopx){
					
						setTranslateY(1);
						
					}else{
						setTranslateY(0);
					}
			    }, 150);
				
			});
		}
	},[ref]);
	


	const setQuizQuestion = (nnquestion,index,action) => {
		if(action == 'changed'){
			
			let nquiz = {...quiz};
			nquiz.meta.questions[index] = nnquestion;
 			setQuiz(nquiz);
 			if(!isEmpty(nnquestion['marked_answer'])){
 				if(typeof nnquestion['marked_answer']==='object' ||  Array.isArray(nnquestion['marked_answer'])){
	 				localStorage.setItem(nnquestion.id,JSON.stringify(nnquestion['marked_answer']));
	 			}else{
	 				localStorage.setItem(nnquestion.id,nnquestion['marked_answer']);
	 			}
 			}else{
 				if(nnquestion['marked_answer'] == null){
 					localStorage.removeItem(nnquestion.id);
 				}
 			}
 			
		}
	}

	const loadQuizQuestions = (nquestionss,action) => {
		if(action == 'show'){
			setCurrentQuestions(nquestionss);
		}
	}

	const checkAnswer = (question,index) => {
		setReady(false);
		let nquestion = evaluatequestion(question,quiz.partial_marking,quiz.negative_marking,parseFloat(quiz.negative_marks),true);
		let nquiz = {...quiz}; 
		nquestion['attempted'] = true;
		nquiz.meta.questions[index] = nquestion;
		

		fetch(window.wplms_quiz_data.api_url+'/user/saveuserquestion' , {
		    method: 'POST',
		    headers: {
		      	'Accept': 'application/json',
      			'Content-Type': 'application/json',
		      	'Authorization':window.wplms_quiz_data.token
		    },
		    body: JSON.stringify(
		    	{
		    		'quiz_id':nquiz.id,
		    		'question':nquestion
	            }
            )
		}).then( res => res.json())
      	.then((data) => {
      		
			
      		setReady(true);
          	setQuiz(nquiz);

      	});
	}
	

	const setQuizExpire = (quiz_id,action) => {
		if(action == 'expired'){
			SubmitQuiz(quiz);
			//trigger submit quiz and end quiz send api call
		}
		
	}

	const startQuiz =() =>{
		setReady(false);
		
		let nquiz = {...quiz}; 
		nquiz.start = true;
		if(quiz.remaining && quiz.remaining > 0){
      		setReady(true);
          	setQuiz(nquiz);
      	}else{
      		fetch(window.wplms_quiz_data.api_url+'/user/quiz/start' , {
			    method: 'POST',
			    headers: {
			      	'Accept': 'application/json',
	      			'Content-Type': 'application/json',
			      	'Authorization':window.wplms_quiz_data.token
			    },
			    body: JSON.stringify(
			    	{
			    		'quiz_id':nquiz.id
		            }
	            )
			}).then( res => res.json())
	      	.then((data) => {
	      		
				
	      		setReady(true);
	          	setQuiz(nquiz);

	      	});
      	}
	}

	const SubmitQuiz = (_quiz=null) => {
		if(!_quiz){
			_quiz = quiz;
		}
		setReady(false);
		let nquiz = {..._quiz};
		let user_marks = 0;
		let max_marks = 0;
		if(nquiz.meta && nquiz.meta.questions && nquiz.meta.questions.length){
			for(let i=0;i<nquiz.meta.questions.length;i++){
				if(!nquiz.meta.questions[i]['attempted'])
					nquiz.meta.questions[i] = evaluatequestion(nquiz.meta.questions[i],quiz.partial_marking,quiz.negative_marking,parseFloat(quiz.negative_marks),false);

				//pushing correct content for results handling in php
				
				nquiz.meta.questions[i]['content'] = nquiz.meta.questions[i].original_content;

				if(!nquiz.meta.questions[i].auto){
					nquiz.meta.questions[i].user_marks = 0;
				}

				user_marks += parseFloat(nquiz.meta.questions[i].user_marks);
				max_marks += parseInt(nquiz.meta.questions[i]['marks']);
				localStorage.removeItem(nquiz.meta.questions[i].id);
			}
		}
		nquiz['marks'] = user_marks.toFixed(2);
		nquiz['max_marks'] = max_marks;
		//submit quiz send api call
		//handle  show quiz results if enabled and show quiz completion message

		fetch(window.wplms_quiz_data.api_url+'/user/submitresult/' , {
		    method: 'POST',
		    headers: {
		      	'Accept': 'application/json',
      			'Content-Type': 'application/json',
		      	'Authorization':window.wplms_quiz_data.token
		    },
		    body: JSON.stringify(
		    	{
		    		'quiz_id':nquiz.id,
	            	'course_id':nquiz.course_id,
	            	'results':nquiz.meta.questions,
	            	'quiz':nquiz
	            }
            )
		}).then( res => res.json())
      	.then((data) => {
          	if(data){
          		setReady(true);
          		nquiz.submitted = true;
				nquiz.start = false;
				if(data.check_results_url){
					nquiz['check_results_url'] = data.check_results_url;
				}
				if(data.completion_message){
					nquiz['meta']['completion_message'] = data.completion_message;
				}
				if(data.retake_html){
					nquiz['retake_html'] = data.retake_html;
				}

				//set correct percentage:
				if(nquiz.meta && nquiz.meta.questions && nquiz.meta.questions.length && !isEmpty(data.correct_data)){
					for(let i=0;i<nquiz.meta.questions.length;i++){
						if(data.correct_data.hasOwnProperty(nquiz.meta.questions[i].id)){
							nquiz.meta.questions[i]['correct_data'] = data.correct_data[nquiz.meta.questions[i].id];
						}
					}
				}

				setQuiz(nquiz);
				var event = document.createEvent("Event");
				event.initEvent("unit_traverse", false, true);
				if(document.querySelector('.unit_content') && document.querySelector('.unit_content')){
					
					document.querySelector('.unit_content').dispatchEvent(event);	

					var postevent = new CustomEvent('react_quiz_submitted', { "detail":{next_unit:data.next_unit}});
                	document.dispatchEvent(postevent);
				}
				
          	}

      	});
		  			
	}

	const saveQuiz = () => {
		if(quiz.meta.questions && quiz.meta.questions.length){
			setReady(false);
			let questions = [];

			quiz.meta.questions.map((question,i)=>{
				let _question = {...question};
				if((_question.marked_answer != null && _question.marked_answer != 'undefined' && !isEmpty(_question.marked_answer)) && !question.attempted){
					_question['correct']  = getCorrectAnswer(_question);
					questions.push(_question);
				}
			});

			fetch(window.wplms_quiz_data.api_url+'/user/savequiz' , {
			    method: 'POST',
			    headers: {
			      	'Accept': 'application/json',
	      			'Content-Type': 'application/json',
			      	'Authorization':window.wplms_quiz_data.token
			    },
			    body: JSON.stringify(
			    	{
			    		'quiz_id':quiz.id,
			    		'questions':questions
		            }
	            )
			}).then( res => res.json())
	      	.then((data) => {
	      		setReady(true);
	      	});
		}
	}

	const renderSwitch = (question,i) => {
		switch(question.type){
			case 'smalltext':
				return <Smalltext question={question} index={i} update={setQuizQuestion}/>
			break;
			case 'single':
				return <Single question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'select':
				return <Select question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'multiple':
				return <Multiple question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'fillblank':
				return <Fillblank question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'sort':
				return <Sort question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'match':
				return <Match question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'truefalse':
				return <TrueFalse question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;
			case 'largetext':
				return <Largetext question={question} index={i} update={setQuizQuestion} quiz_id={quiz.id}/>
			break;

			default:
			break;
		}
	}

	const checkPopup = (type,action) => {
		if(action == "trigger"){
			switch(type){
				case 'submit':
					SubmitQuiz(quiz);
					setsubmitPopupActive(false);
				break;
				case 'start':
					startQuiz(quiz);
					setstartPopupActive(false);
				break;
			}
		}
		if(action == "nottrigger"){
			switch(type){
				case 'submit':
					setsubmitPopupActive(false);
				break;
				case 'start':
					setstartPopupActive(false);
				break;
			}
		}
	}

	const _submitQuiz = () => {
		
		if(window.wplms_quiz_data.submit_popup){
			setsubmitPopupActive(true);
		}else{
			SubmitQuiz();
		}
	}

	const _startQuiz = () => {
		if(window.wplms_quiz_data.start_popup){
			setstartPopupActive(true);
		}else{
			startQuiz();
		}
	}

	let quiz_duration = 0;
	if(quiz.meta && quiz.meta.duration){
		quiz_duration = quiz.meta.duration;
	}
	if(quiz && quiz.remaining && quiz.remaining > 0){
		quiz_duration = quiz.remaining;
	}

	let loadingclass = '';
	let loadingwrapper = 'loading_quiz';
	if(ready){
		loadingclass = 'disabled';
		loadingwrapper = loadingwrapper+' disabled';
	}

	let qdclass = 'incoursequiz_details';
	if(translatey){
		qdclass = 'incoursequiz_details fixed';
	}


	let submit_confirm = window.wplms_quiz_data.translations.submit_quiz_confirm;
	if(quiz.meta && quiz.meta.questions){
		let marked_all = 1;
		quiz.meta.questions.map(function(question){
			if(!question.marked_answer){
				marked_all = 0;
				return;
			}
		});
		if(!marked_all){
			submit_confirm = window.wplms_quiz_data.translations.unanswered_confirm+submit_confirm;
		}
	}
	
	if(props.type == 'incourse'){
		return (
			<Fragment>
				<ConfirmPopup active={submitPopupActive} update={checkPopup} type="submit" content={submit_confirm} yes={window.wplms_quiz_data.translations.yes} no={window.wplms_quiz_data.translations.no} yesfunction="submitQuiz" />
				<ConfirmPopup active={startPopupActive} update={checkPopup} type="start" content={window.wplms_quiz_data.translations.start_quiz_confirm} yes={window.wplms_quiz_data.translations.yes} no={window.wplms_quiz_data.translations.no} yesfunction="startQuiz" />
				<div className="incourse">
					<div className={loadingwrapper}>
						<div id="ajaxloader" className={loadingclass}></div>
					</div>

					<div className={qdclass} ref={(e)=>{
						
							let nref = ref;
							if(ready && e && !nref){
								nref=e;
								setRef(nref);
							} 
						}}>
						<div>
						{
					  		(quiz && quiz.meta && quiz.meta.duration && parseInt(quiz.meta.duration) < 863913600)?
				  			<QuizTimer 
				  				duration={quiz_duration} 
				  				update={setQuizExpire} 
				  				quiz_id={quiz.id} 
				  				start={quiz.start}
			  				/>
				  			:''
				  		}
				  		</div>
				  		<div className="incousre_quiz_button">

				  		{
				  			(ready && !quiz.start && !quiz.submitted)?
					  				
			  					(quiz.remaining && quiz.remaining > 0)?
				  					<a className="continue_quiz button" onClick={startQuiz}>
				  						{window.wplms_quiz_data.translations.continue}
				  					</a>
			  					:
				  					<a className="start_quiz button full" onClick={_startQuiz}>
				  						{window.wplms_quiz_data.translations.start}
				  					</a>
				  			:''
				  		}

				  		{
				  			(quiz.start && !quiz.submitted)?
						  		<a className="start_quiz button" onClick={saveQuiz}>
					  				{window.wplms_quiz_data.translations.save_quiz}
								</a>
				  			:''
				  		}

				  		{
				  			(quiz.start && !quiz.submitted)?
						  		<a className="submitreact_quiz button" onClick={_submitQuiz}>
					  				{window.wplms_quiz_data.translations.submit}
								</a>
				  			:''
				  		}

				  		{
				  			(!quiz.start && quiz.submitted && quiz.check_results_url)?
						  		<a className="check_results button quiz_results_popup" href={quiz.check_results_url}>
					  				{window.wplms_quiz_data.translations.check_results}
								</a>
				  			:''
				  		}
				  		</div>

				  		
				  		
			  		</div>

					<div className="quiz_questions_content">
			  			
					    <div className="">
					  	{
					  		(!quiz.start && !quiz.submitted)?
					  		<div className="quiz_content" dangerouslySetInnerHTML={{ __html: (quiz && quiz.content)?quiz.content:'' }}></div>
					  		:''
					  	}
					  	{
					  		(!quiz.start && quiz.submitted)?
					  		<div className="">
					  		<div className="quiz_content" dangerouslySetInnerHTML={{ __html: quiz.meta.completion_message }}></div>
					  		<div className="" id="total_marks">
					  		{window.wplms_quiz_data.translations.total_marks}
					  		{
					  			(quiz.meta && quiz.meta.auto)?
					  			<strong><span>{quiz.marks}</span> / {quiz.max_marks}</strong>
					  			:(quiz.meta && quiz.meta.status==4 && quiz.submitted)?
					  			<strong><span>{quiz.marks}</span> / {quiz.max_marks}</strong>

					  			:<strong><i class="icon-alarm"></i></strong>
					  		}
					  		

					  		
					  		</div>
					  		{
					  			(!quiz.start && quiz.submitted && quiz.retake_html)?
						  		<div dangerouslySetInnerHTML={{ __html: quiz.retake_html }}></div>
						  		:''
					  		}
					  		</div>
					  		:''
					  	}
					  	{
				  			(quiz && quiz.meta && quiz.meta.questions && quiz.submitted && quiz.meta.auto && quiz.show_advance_stats)?
				  				<QuizStatsChart quiz={quiz} />
				  			:''
				  		}
				  		{
				  			(quiz && quiz.meta && quiz.meta.questions && (quiz.start || quiz.submitted))?
				  			quiz.meta.questions.map((question,i)=>{
				  				if(currentQuestions.indexOf(i) === -1){
				  					return;
				  				}
				  				return 	<div className="question">
				  							
				  							<span class="marks"><i class="icon-check-5"></i>{question.marks}
				  							
				  							</span>
				  							<QuestionHint question={question} update={setQuizQuestion} index={i}/>
								 			{renderSwitch(question,i)}
								 			
								 			{
								 				(!question.attempted && quiz.check_answer && !quiz.submitted)?
						  						<div className="quiz_check_answer button" onClick={(e)=>{
						  							checkAnswer(question,i)
						  						}}>
									  				{window.wplms_quiz_data.translations.check_answer}
												</div>
						  						:''
								 			}

								 			{
								 				(question.attempted && quiz.check_answer)?
								 				<CheckAnswer question={question}/>
								 				:''
								 			}
								 			{
												(question.attempted  && question.show_correct_answer)?
												<div className="explanation">
													<div dangerouslySetInnerHTML={{ __html:question.explanation }}></div>
												</div>
												:''
											}
								 		</div>;
				  			})
				  			:''
				  		}
				  		{
				  			(quiz && quiz.meta && quiz.meta.questions && (quiz.start || quiz.submitted))?
				  			<QuizPagination quiz={quiz} currentQuestions={currentQuestions} update={loadQuizQuestions}/>
				  			:''
				  		}
				  		
				  		
				  		</div>

			  		</div>
		 		</div>
			
		  	</Fragment>
		);

	}else{

		return (
			<Fragment>
				
				<ConfirmPopup active={submitPopupActive} update={checkPopup} type="submit" content={submit_confirm} yes={window.wplms_quiz_data.translations.yes} no={window.wplms_quiz_data.translations.no} yesfunction="submitQuiz" />
				<ConfirmPopup active={startPopupActive} update={checkPopup} type="start" content={window.wplms_quiz_data.translations.start_quiz_confirm} yes={window.wplms_quiz_data.translations.yes} no={window.wplms_quiz_data.translations.no} yesfunction="startQuiz" />

				<div className="row">
					<div className={loadingwrapper}>
						<div id="ajaxloader" className={loadingclass}></div>
					</div>
					<div className="quiz_questions_content col-md-9 col-md-push-3">
			  			
					    <div class="main_content">
					  	{
					  		(!quiz.start && !quiz.submitted)?
					  		<div className="quiz_content" dangerouslySetInnerHTML={{ __html: (quiz && quiz.content)?quiz.content:'' }}></div>
					  		:''
					  	}

					  	{
					  		(!quiz.start && quiz.submitted)?
					  		<div className="quiz_content_wrapper">
					  		<div className="quiz_content" dangerouslySetInnerHTML={{ __html: quiz.meta.completion_message }}></div>
					  		<div className="" id="total_marks">
					  		{window.wplms_quiz_data.translations.total_marks}
					  		{
					  			(quiz.meta && quiz.meta.auto)?
					  			<strong><span>{quiz.marks}</span> / {quiz.max_marks}</strong>
					  			:(quiz.meta && quiz.meta.status==4 && quiz.submitted)?
					  			<strong><span>{quiz.marks}</span> / {quiz.max_marks}</strong>

					  			:<strong><i class="icon-alarm"></i></strong>
					  		}
					  		

					  		
					  		</div>
					  		{
					  			(!quiz.start && quiz.submitted && quiz.retake_html)?
						  		<div dangerouslySetInnerHTML={{ __html: quiz.retake_html }}></div>
						  		:''
					  		}
					  		</div>
					  		:''
					  	}
					  	{
				  			(quiz && quiz.meta && quiz.meta.questions && quiz.submitted && quiz.meta.auto && quiz.show_advance_stats)?
				  				<QuizStatsChart quiz={quiz} />
				  			:''
				  		}
				  		{
				  			(quiz && quiz.meta && quiz.meta.questions && (quiz.start || quiz.submitted))?
				  			quiz.meta.questions.map((question,i)=>{
				  				if(currentQuestions.indexOf(i) === -1){
				  					return;
				  				}
				  				return 	<div className="question">
				  							
				  							<span class="marks"><i class="icon-check-5"></i>{question.marks}
				  							
				  							</span>
				  							<QuestionHint question={question} update={setQuizQuestion} index={i}/>
								 			{renderSwitch(question,i)}
								 			
								 			{
								 				(!question.attempted && quiz.check_answer && !quiz.submitted)?
						  						<div className="quiz_check_answer button" onClick={(e)=>{
						  							checkAnswer(question,i)
						  						}}>
									  				{window.wplms_quiz_data.translations.check_answer}
												</div>
						  						:''
								 			}

								 			{
								 				(question.attempted && quiz.check_answer)?
								 				<CheckAnswer question={question}/>
								 				:''
								 			}
								 			{
												(question.attempted  && question.show_correct_answer)?
												<div className="explanation">
													<div dangerouslySetInnerHTML={{ __html:question.explanation }}></div>
												</div>
												:''
											}
								 		</div>;
				  			})
				  			:''
				  		}
				  		{
				  			(quiz && quiz.meta && quiz.meta.questions && (quiz.start || quiz.submitted))?
				  			<QuizBar quiz={quiz} currentQuestions={currentQuestions} update={loadQuizQuestions}/>
				  			:''
				  		}
				  		
				  		</div>
			  		</div>

			  		<div className="col-md-3 col-md-pull-9">
				  		<div className="quiz_details">

				  		{
				  			(ready && !quiz.start && !quiz.submitted)?
					  				
			  					(quiz.remaining && quiz.remaining > 0)?
				  					<a className="start_quiz button" onClick={startQuiz}>
				  						{window.wplms_quiz_data.translations.continue}
				  					</a>
			  					:
				  					<a className="start_quiz button" onClick={_startQuiz}>
				  						{window.wplms_quiz_data.translations.start}
				  					</a>
				  			:''
				  		}

				  		{
				  			(quiz.start && !quiz.submitted)?
						  		<a className="start_quiz button" onClick={saveQuiz}>
					  				{window.wplms_quiz_data.translations.save_quiz}
								</a>
				  			:''
				  		}

				  		{
				  			(quiz.start && !quiz.submitted)?
						  		<a className="submitreact_quiz button" onClick={_submitQuiz}>
					  				{window.wplms_quiz_data.translations.submit}
								</a>
				  			:''
				  		}

				  		{
				  			(!quiz.start && quiz.submitted && quiz.check_results_url)?
						  		<a className="check_results button" href={quiz.check_results_url}>
					  				{window.wplms_quiz_data.translations.check_results}
								</a>
				  			:''
				  		}

				  		{
				  			(quiz && quiz.meta && quiz.meta.duration && parseInt(quiz.meta.duration) < 863913600)?
				  			<QuizTimer 
				  				duration={quiz_duration} 
				  				update={setQuizExpire} 
				  				quiz_id={quiz.id} 
				  				start={quiz.start}
			  				/>
				  			:''
				  		}
				  		{
				  			<QuestionList currentQuestions={currentQuestions} quiz={quiz} update={loadQuizQuestions}/>
				  		}
				  		</div>
			  		</div>
			  		
		 		</div>
			
		  	</Fragment>
		);
	}
	
}

if(window.wplms_quiz_data.in_course == 1){
	document.addEventListener('unit_traverse',(e)=>{
		if(document.querySelector("#wplms_quiz") ){
			render( <VibeQuiz quizid={document.querySelector("#wplms_quiz").getAttribute('data-id')} type={document.querySelector("#wplms_quiz").getAttribute('data-type')}/> ,
			    document.querySelector("#wplms_quiz") 
			);
		}
		
	});
}else{
	if(document.querySelector("#wplms_quiz") ){
		render( <VibeQuiz quizid={document.querySelector("#wplms_quiz").getAttribute('data-id')} type={document.querySelector("#wplms_quiz").getAttribute('data-type')}/> ,
		    document.querySelector("#wplms_quiz") 
		);
	}
}



	

